function [misses, doubles] = importImages(sourcepath, txtfile, simulate)
% [misses, doubles] = importImages(sourcepath, txtfile, simulate)
%
% import images that have been downloaded from e.g. Flickr with the python
% script that is also part of this package
%
% sourcepath: directory path to the images to import
% txtfile: text file containing the image ids and keyword list in the form:
%          id \t <<kw1>> <<kw2>> <<kw3>> .... \n
% simulate: boolean variable to run script as a simulation or not
%
%
% misses: image files that appear in the text file but could not be found
% double: image files that already exist in the database
%
% example usage:
% importImages('./flickr/images/', './flickr/flickr_id_kw.txt', 1);

if simulate == 0
    answer = input('This is for real since simulate is disabled.\nAre you sure you want to continue? (YES, NO, keyboard): ', 's');
    if ~strcmp(answer, 'YES') && ~strcmp(answer, 'keyboard')
        error('aborting import');
    end
    if strcmp(answer, 'keyboard')
        keyboard;
    end
end

% keyboard
init;
fid = fopen(txtfile);
c = textscan(fid, '%u64 %s', 'delimiter', '\t', 'bufsize', 100000);
fclose(fid);
ids = c{1};
kw = c{2};

importfile = fopen([txtfile '_import.txt'], 'w');

% open database for append, but backup it first
f_database = opts.DB;
c = clock;
copyfile(f_database, ['./database_backup/' num2str(c(1)) '-' num2str(c(2)) '-' num2str(c(3)) '-' num2str(c(4)) '-' num2str(c(5)) '__' f_database]);
database = fopen(f_database, 'a');


n = 0;

misses = [];
doubles = [];

for i = 1:length(ids)
    dofile = 1;
    id = ids(i);
    fprintf('%0.0f ...', id);
    
    sourcefile = [sourcepath num2str(id) '.jpg'];
    targetfile = sprintf(opts.imagePath, getPrefix(id), num2str(id));
    
    if ~exist(sourcefile, 'file')
        fprintf(' no sourcefile: %s\n', sourcefile);
        misses = [misses id];
        dofile = 0;
    end
    
    if exist(targetfile, 'file')
        fprintf(' existing targetfile: %s\n', targetfile);
        doubles = [doubles id];
        dofile = 0;
    end
    
    if ~simulate
        if dofile == 1
            fprintf(' move\n');
            try
                movefile(sourcefile, targetfile);
            catch % create directory if not existant
                directory = regexp(targetfile, '.*\/\d\d\/', 'match');
                directory = directory{1};
                mkdir(directory);
                movefile(sourcefile, targetfile);
            end
            n = n+1;
            fprintf(importfile, '%0.0f\t%s\r', ids(i), kw{i});
            fprintf(database, '%0.0f\t%s\r', ids(i), kw{i});
        end
    else
        if dofile == 1
            fprintf(' simulate\n%s -> %s\n', sourcefile, targetfile);
            n = n+1;
            fprintf(importfile, '%0.0f\t%s\r', ids(i), kw{i});
        end
    end
    
end

fclose(importfile);
% keyboard
fprintf('\n\n');
if simulate
    fprintf('SIMULATION ENDED\n');
else
    fprintf('IMPORT ENDED\n');
end

fprintf('%d files imported\n', n);
fprintf('%d files missing:\n', length(misses));
if length(misses) > 0
    fprintf(num2str(misses));
    fprintf('\n');
end
fprintf('%d files already in target:\n', length(doubles));
if length(doubles) > 0
    fprintf(num2str(doubles));
    fprintf('\n');
end

fprintf('A list of imported images has been written to %s\n', [txtfile '_import.txt']);
